import './loading-status.less'

var loadingStatus = {}
loadingStatus.config = {
    loadingText: '正在加载',
    successText: '加载成功',
    emptyText: '暂无数据',
    errorText: '加载失败'
}

loadingStatus.install = (Vue, options) => {
    var loadStatusComponent = Vue.extend({
        template: `<div @click="$emit('feedback', fnMessage.feedback)" :style="{'height': fnHeight}" :class="{'global': global}" class="loading-status">
                        <div class="loading-body">
                            <div :class="fnMessage.class" class="loading-content">
                                <i :class="fnMessage.icon"></i>
                                <p v-if="fnMessage.text">{{ fnMessage.text }}</p>
                            </div>
                        </div>
                    </div>`,
        props: {
            status: {
                type: Array,
                default () {
                    return [true, loadingStatus.config.loadingText]
                }
            },
            global: {
                type: Boolean,
                default: false
            },
            height: {
                type: [String, Number],
                default: 200
            }
        },
        computed: {
            fnMessage () {
                if (this.status && this.status.length) {
                    let status = this.status[0]
                    if (status === 1) {
                        // 加载成功
                        return {
                            class: 'success',
                            icon: 'fa fa-check-circle',
                            text: this.status[1] === undefined ? loadingStatus.config.successText : this.status[1],
                            feedback: 1
                        }
                    }
                    else if (status === 0) {
                        // 暂无数据
                        return {
                            class: 'empty',
                            icon: 'fa fa-frown-o',
                            text: this.status[1] === undefined ? loadingStatus.config.emptyText : this.status[1],
                            feedback: 0
                        }
                    }
                    else if (status === -1) {
                        // 加载失败
                        return {
                            class: 'error',
                            icon: 'fa fa-exclamation-circle',
                            text: this.status[1] === undefined ? loadingStatus.config.errorText : this.status[1],
                            feedback: -1
                        }
                    }
                    else {
                        // 正在加载
                        return {
                            class: 'loading',
                            icon: 'fa fa-circle-o-notch fa-spin',
                            text: this.status[1] === undefined ? loadingStatus.config.loadingText : this.status[1],
                            feedback: true
                        }
                    }
                }
                else {
                    // 正在加载
                    return {
                        class: 'loading',
                        icon: '',
                        text: loadingStatus.config.loadingText,
                        feedback: true
                    }
                }
            },
            fnHeight () {
                if (this.global) {
                    return
                }
                if (this.height > 0) {
                    return this.height + 'px'
                }
                else {
                    return this.height
                }
            }
        }
    })
    Vue.component('loading-status', loadStatusComponent)
}

if (window.Vue) {
    Vue.use(loadingStatus)
}

export default loadingStatus